Learn R Programming

dimensionsR (version 0.0.3)

altmetric: Gather altmetric metadata from a DOI

Description

It gathers altemtric metadata from a DOI using Altmetric API (www.altmetric.com). A single research output may live online in multiple websites and can be talked about across dozens of different platforms.

Altmetric is a search engine which collects and collates all of this disparate information to obtain an informative view of the online activity surrounding your scholarly content.

Usage

altmetric(doi = "10.1016/j.joi.2017.08.007")

Arguments

doi

is a character. It contains a list of DOIs. A DOI is a persistent identfier of a scholarly document.

Value

a data frame. Each row contains the full metadata record for each scholarly document.

For more extensive information about Altmetric, please visit: https://www.altmetric.com

Examples

Run this code
# NOT RUN {
# }
# NOT RUN {
doi = "10.1016/j.joi.2017.08.007"

df <- altmetric(doi = doi)
# }
# NOT RUN {
# }

Run the code above in your browser using DataLab